-- -------------------------------------------------------------------
-- Tests iPhoto's version to be sure it meets our requirements.
-- -------------------------------------------------------------------
on verifyVersion(requiredVersionNum)
	set versionOK to true -- let's assume it's valid now since it's had this feature for a while
	tell application "iPhoto"
		set versionString to version
		set versionNum to character 1 of versionString as integer
		if versionNum < requiredVersionNum then set versionOK to false
	end tell
	return versionOK
end verifyVersion

-- -------------------------------------------------------------------
-- Returns a list of photo ablums in iPhoto.
-- -------------------------------------------------------------------
on getAlbums()
	set regularAlbumList to {}
	tell application "iPhoto"
		set albumList to name of every album
		repeat with currentAlbum in albumList
			set albumType to type of album currentAlbum
			if ((albumType as string) is "regular album" or (albumType as string) is "published album") then set regularAlbumList to regularAlbumList & currentAlbum
		end repeat
	end tell
	return regularAlbumList
end getAlbums

-- -------------------------------------------------------------------
-- Creates the specified album if it doesn't exist.
-- -------------------------------------------------------------------
on createAlbum(albumName)
	tell application "iPhoto"
		if (not (exists album albumName)) then new album name albumName
		select album albumName
	end tell
end createAlbum

-- -------------------------------------------------------------------
-- Returns a list of photos in the specified album. Creates
-- the album if it doesn't exist.
-- -------------------------------------------------------------------
on getAlbumPhotoFileNames(albumName)
	set photoFiles to {}
	tell application "iPhoto"
		if (not (exists album albumName)) then new album name albumName
		select album albumName
		set photoList to photos in album albumName
		repeat with currentPhoto in photoList
			set photoFiles to photoFiles & image filename of currentPhoto
		end repeat
	end tell
	return photoFiles
end getAlbumPhotoFileNames

-- -------------------------------------------------------------------
-- Imports the specified file into iPhoto and adds it to the 
-- specified album with the specified title. 
-- -------------------------------------------------------------------
on importPhotoFileInAlbum(photoFileName, albumName)
	set the_file to (POSIX file photoFileName)
	tell application "iPhoto"
		activate
		if not (exists album albumName) then new album name albumName
		select album albumName
		import from the_file as alias to album albumName with force copy
	end tell
end importPhotoFileInAlbum

-- -------------------------------------------------------------------
-- Removes the specified photo from the library.
-- -------------------------------------------------------------------
on removePhotoFileFromAlbum(photoFileName, albumName)
	set libraryAlbum to my getLibraryAlbumName()
	tell application "iPhoto"
		set photoList to every photo in album albumName
		repeat with currentPhoto in photoList
			if image filename of currentPhoto contains photoFileName then remove currentPhoto from album libraryAlbum
		end repeat
	end tell
end removePhotoFileFromAlbum

-- -------------------------------------------------------------------
-- Removes all photos from the library and album.
-- -------------------------------------------------------------------
on removeAllPhotoFilesFromAlbum(albumName)
	set libraryAlbum to my getLibraryAlbumName()
	tell application "iPhoto"
		set photoList to every photo in album albumName
		repeat with currentPhoto in photoList
			remove currentPhoto from album libraryAlbum
		end repeat
	end tell
end removeAllPhotoFilesFromAlbum

-- -------------------------------------------------------------------
-- Returns the name of the library album.
-- -------------------------------------------------------------------
on getLibraryAlbumName()
	set libraryAlbum to "Library"
	tell application "iPhoto"
		set albumList to name of every album
		repeat with currentAlbum in albumList
			set albumType to type of album currentAlbum
			if (albumType as string) is "photo library album" then set libraryAlbum to (currentAlbum as string)
		end repeat
	end tell
	return libraryAlbum
end getLibraryAlbumName
